markdown

package
v1.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 17, 2026 License: MIT Imports: 13 Imported by: 0

Documentation

Overview

Package markdown implements the generic markdown plan/spec adapter.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func InferDirectoryTag

func InferDirectoryTag(relPath string) string

InferDirectoryTag extracts a meaningful tag from the source path's directory structure. Returns empty string for generic directories and root-level files.

func MatchSourceRules

func MatchSourceRules(repoRel string, sourcePaths []string, rules []config.SourceRule) (kind, subtype string, extraTags []string, matched bool)

MatchSourceRules returns kind/subtype/tags from the first matching rule. Rules match paths relative to each configured markdown source directory (repo-relative).

Types

type Adapter

type Adapter struct{}

Adapter discovers and parses generic markdown plans/specs.

func (*Adapter) Discover

func (a *Adapter) Discover(ctx context.Context, repoRoot string, cfg *config.RepoConfig) ([]adapters.Candidate, error)

func (*Adapter) Name

func (a *Adapter) Name() string

Jump to