Documentation
¶
Overview ¶
Package markdown implements the generic markdown plan/spec adapter.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func InferDirectoryTag ¶
InferDirectoryTag extracts a meaningful tag from the source path's directory structure. Returns empty string for generic directories and root-level files.
func MatchSourceRules ¶
func MatchSourceRules(repoRel string, sourcePaths []string, rules []config.SourceRule) (kind, subtype string, extraTags []string, matched bool)
MatchSourceRules returns kind/subtype/tags from the first matching rule. Rules match paths relative to each configured markdown source directory (repo-relative).
Types ¶
Click to show internal directories.
Click to hide internal directories.