sourcecontext

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 29, 2026 License: MIT Imports: 11 Imported by: 0

Documentation

Overview

Package sourcecontext indexes bounded source files as retrieval context.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Adapter

type Adapter struct{}

Adapter discovers source files that are useful as query-focused AI context.

func (*Adapter) AcceptsFile

func (a *Adapter) AcceptsFile(rel string, size int64, cfg *config.RepoConfig) bool

func (*Adapter) Discover

func (a *Adapter) Discover(ctx context.Context, repoRoot string, cfg *config.RepoConfig) ([]adapters.Candidate, error)

func (*Adapter) DiscoverFile

func (a *Adapter) DiscoverFile(ctx context.Context, file adapters.FileCandidate, cfg *config.RepoConfig) ([]adapters.Candidate, error)

func (*Adapter) Name

func (a *Adapter) Name() string

Jump to